<?php
include 'connexion_db.php'; // Connexion centralisée

// Vérifie que l'ID est présent
if (!isset($_GET['id_bon'])) {
    die("ID non spécifié !");
}

$id = intval($_GET['id_bon']);

// Va chercher le bon dans la base
$sql = "SELECT * FROM bon_travail WHERE id_bon = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    die("Bon de travail introuvable.");
}

$bon = $result->fetch_assoc();

// Traductions pour affichage lisible
$techniciens = [
    'guillaume' => 'Guillaume Lejeune',
    'remi' => 'Remi Lessard',
    'yan' => 'Yan Larocque'
];

$succursales = [
    'stgregoire' => 'St-Grégoire',
    'gentilly' => 'Gentilly'
];

$technicien_affiche = $techniciens[$bon['technicien']] ?? $bon['technicien'];
$succursale_affiche = $succursales[$bon['succursale']] ?? $bon['succursale'];

?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Bon de travail - Impression</title>
    <link rel="stylesheet" href="css/bon_impression.css">
    <link rel="stylesheet" href="css/menu.css">
</head>
<body>

<?php include("menu.php"); ?>

<div class="entete">
  <div class="logo">
    <img src="images/logo.png" alt="Logo">
  </div>
  <div class="adresse">
    <p><strong>Succursale St-Grégoire</strong><br>
    17240 Boul. des Acadiens<br>
    St-Grégoire, 819-383-9818</p>
  </div>
  <div class="adresse">
    <p><strong>Succursale Gentilly</strong><br>
    1485 Boul. Bécancour<br>
    Gentilly, 819-383-9818</p>
  </div>
</div>

    <div class="contenu-bon">
	<p><strong>Bon de travail #<?= htmlspecialchars($id) ?></strong></p>
        <p><strong>Nom du client :</strong> <?= htmlspecialchars($bon['nom_prenom']) ?></p>
        <p><strong>Téléphone :</strong> <?= htmlspecialchars($bon['telephone']) ?> poste <?= htmlspecialchars($bon['poste']) ?></p>
        <p><strong>Date :</strong> <?= htmlspecialchars($bon['date_creation']) ?></p>
	<p><strong>Technicien :</strong> <?= htmlspecialchars($technicien_affiche) ?></p>
	<p><strong>Succursale :</strong> <?= htmlspecialchars($succursale_affiche) ?></p>
        <p><strong>Appareil déposé :</strong> <?= htmlspecialchars($bon['appareil_deposer']) ?></p>
        <p><strong>Code :</strong> <?= htmlspecialchars($bon['code']) ?></p>
        <p><strong>Transfo du client :</strong> <?= htmlspecialchars($bon['transfo']) ?></p>
        <p><strong>Commentaires :</strong><br><?= nl2br(htmlspecialchars($bon['commentaire'])) ?></p>
        <br><br>
        <p><strong>Signature du client : _______________________________</strong></p>
    </div>

<div style="text-align:center; margin-top: 30px;">
    <button onclick="window.print()" style="padding: 10px 20px; font-size: 16px; margin-right: 10px;">Imprimer</button>
    <?php if (isset($_GET['id_bon'])): ?>
        <a href="modif_bon.php?id_bon=<?= htmlspecialchars($_GET['id_bon']) ?>" style="text-decoration: none;">
            <button style="padding: 10px 20px; font-size: 16px;">Modifier</button>
        </a>
    <?php endif; ?>
</div>

</body>
</html>
