<?php
include("connexion_db.php");

// Affichage des erreurs pour debug
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if (!isset($_GET['id_bon'])) {
    echo "ID du bon non spécifié.";
    exit;
}

$id_bon = intval($_GET['id_bon']);

$sql = "SELECT * FROM bon_travail WHERE id_bon = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $id_bon);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo "Bon introuvable.";
    exit;
}

$bon = $result->fetch_assoc();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Modifier Bon de Travail</title>
    <link rel="stylesheet" href="css/bon_travail.css">
    <link rel="stylesheet" href="css/menu.css">
</head>
<body>

<?php include("menu.php"); ?>

<div class="container">
    <h1>Modifier le Bon de Travail #<?= htmlspecialchars($id_bon) ?></h1>

    <form action="traitement_modif_bon.php" method="post">
        <input type="hidden" name="id_bon" value="<?= $id_bon ?>">

        <label for="nom_prenom">Nom du client</label>
        <input type="text" name="nom_prenom" id="nom_prenom" value="<?= htmlspecialchars($bon['nom_prenom']) ?>" required>

        <label for="telephone">Téléphone</label>
        <input type="text" name="telephone" id="telephone" value="<?= htmlspecialchars($bon['telephone']) ?>">

        <label for="poste">Poste</label>
        <input type="text" name="poste" id="poste" value="<?= htmlspecialchars($bon['poste']) ?>">

        <label for="date_creation">Date de création</label>
        <input type="date" name="date_creation" id="date_creation" value="<?= htmlspecialchars($bon['date_creation']) ?>" required>

        <label for="technicien">Technicien</label>
        <input type="text" name="technicien" id="technicien" value="<?= htmlspecialchars($bon['technicien']) ?>">

        <label for="succursale">Succursale</label>
        <select name="succursale" id="succursale">
            <option value="stgregoire" <?= $bon['succursale'] == 'stgregoire' ? 'selected' : '' ?>>Saint-Grégoire</option>
            <option value="drummond" <?= $bon['succursale'] == 'drummond' ? 'selected' : '' ?>>Drummondville</option>
            <option value="sherbrooke" <?= $bon['succursale'] == 'sherbrooke' ? 'selected' : '' ?>>Sherbrooke</option>
        </select>

        <label for="appareil_deposer">Appareil déposé</label>
        <input type="text" name="appareil_deposer" id="appareil_deposer" value="<?= htmlspecialchars($bon['appareil_deposer']) ?>">

        <label for="code">Code</label>
        <input type="text" name="code" id="code" value="<?= htmlspecialchars($bon['code']) ?>">

        <label for="transfo">Transfert</label>
        <input type="text" name="transfo" id="transfo" value="<?= htmlspecialchars($bon['transfo']) ?>">

        <label for="commentaire">Commentaire</label>
        <textarea name="commentaire" id="commentaire"><?= htmlspecialchars($bon['commentaire']) ?></textarea>

        <div class="form-footer">
            <button type="submit">Enregistrer les modifications</button>
        </div>
    </form>
</div>

</body>
</html>
